import { __decorate, __param } from 'tslib';
import { Input, HostListener, Directive, Inject, ElementRef, NgModule } from '@angular/core';

let NgxPatternDirective = class NgxPatternDirective {
    constructor(host) {
        this.host = host;
    }
    ngOnChanges(changes) {
        if (this.ngxPattern) {
            if (typeof this.ngxPattern === 'string') {
                this.regex = new RegExp(`^${this.ngxPattern}$`, 'g');
            }
            else {
                this.regex = this.ngxPattern;
            }
        }
    }
    onKeyDown(e) {
        if (this.regex && !e.ctrlKey && !isSpecialKey(e.key)) {
            if (!this.validWithChange(e.key)) {
                e.preventDefault();
            }
        }
    }
    onInput() {
        if (!this.textIsValid(this.currentValue)) {
            // Mobile browsers don't support keydown preventDefault and return
            // Unidentified for the pressed key. We need to detect the change on input event and undo.
            document.execCommand('undo');
        }
    }
    onPaste(e) {
        const pastedInput = e.clipboardData.getData('text/plain');
        if (!this.validWithChange(pastedInput)) {
            e.preventDefault();
        }
    }
    onDrop(e) {
        const textData = e.dataTransfer.getData('text');
        if (!this.validWithChange(textData)) {
            e.preventDefault();
        }
    }
    get currentValue() {
        return this.inputEl ? this.inputEl.value : undefined;
    }
    validWithChange(delta) {
        const { value: current, selectionStart, selectionEnd, } = this.inputEl;
        const updated = current.substring(0, selectionStart) + delta + current.substring(selectionEnd + 1);
        return this.textIsValid(updated);
    }
    textIsValid(text) {
        const result = !text || this.regex.test(text);
        this.regex.lastIndex = 0;
        return result;
    }
    get inputEl() {
        return this.host.nativeElement;
    }
};
__decorate([
    Input()
], NgxPatternDirective.prototype, "ngxPattern", void 0);
__decorate([
    HostListener('keydown', ['$event'])
], NgxPatternDirective.prototype, "onKeyDown", null);
__decorate([
    HostListener('input', [])
], NgxPatternDirective.prototype, "onInput", null);
__decorate([
    HostListener('paste', ['$event'])
], NgxPatternDirective.prototype, "onPaste", null);
__decorate([
    HostListener('drop', ['$event'])
], NgxPatternDirective.prototype, "onDrop", null);
NgxPatternDirective = __decorate([
    Directive({
        selector: '[ngxPattern]'
    }),
    __param(0, Inject(ElementRef))
], NgxPatternDirective);
/** @see https://developer.mozilla.org/bg/docs/Web/API/KeyboardEvent/key/Key_Values */
function isSpecialKey(key) {
    return key.length > 1;
}

let NgxPatternModule = class NgxPatternModule {
};
NgxPatternModule = __decorate([
    NgModule({
        declarations: [NgxPatternDirective],
        imports: [],
        exports: [
            NgxPatternDirective
        ]
    })
], NgxPatternModule);

/*
 * Public API Surface of ngx-pattern
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxPatternDirective, NgxPatternModule };
//# sourceMappingURL=ngx-pattern.js.map
